@@ -251,6 +251,13 @@ void JobTypeListView::slotImportScheduleType()
     KCalendarCore::ICalFormat icalformat;
     QTimeZone timezone = QDateTime::currentDateTime().timeZone();
     KCalendarCore::MemoryCalendar::Ptr cal(new KCalendarCore::MemoryCalendar(timezone));
+    // 先加载ICS文件内容，才能读取到自定义属性
+    auto ok = icalformat.load(cal, filename);
+    if (!ok) {
+        qCWarning(ClientLogger) << "can not load ics file from" << filename;
+        return;
+    }
+
     auto typeID = cal->nonKDECustomProperty("X-DDE-CALENDAR-TYPE-ID");
     auto typeName = cal->nonKDECustomProperty("X-DDE-CALENDAR-TYPE-NAME");
     auto typeColor = cal->nonKDECustomProperty("X-DDE-CALENDAR-TYPE-COLOR");
@@ -278,44 +285,26 @@ void JobTypeListView::slotImportScheduleType()
     // 显示等待对话框
     m_waitDialog->show();
 
-    // Check if schedule type with same name already exists
-    DScheduleType::List existingTypes = account->getScheduleTypeList();
-    bool typeExists = false;
-    for (const DScheduleType::Ptr& existingType : existingTypes) {
-        if (existingType->displayName() == typeName) {
-            typeID = existingType->typeID();
-            typeExists = true;
-            qCDebug(ClientLogger) << "Schedule type already exists with ID:" << typeID << "name:" << typeName;
-            break;
-        }
-    }
+    DScheduleType::Ptr type(new DScheduleType());
+    type->setColorCode(typeColor);
+    type->setDisplayName(typeName);
 
     QEventLoop event;
-
-    if (!typeExists) {
-        // Create new schedule type if it doesn't exist
-        DScheduleType::Ptr type(new DScheduleType());
-        type->setColorCode(typeColor);
-        type->setDisplayName(typeName);
-
-        // 创建日程类型
-        account->createJobType(type, [&event, &typeID](CallMessge msg) {
-            if (msg.code == 0) {
-                // 记录创建的类型ID
-                typeID = msg.msg.toString();
-                qCDebug(ClientLogger) << "Created schedule type with ID:" << typeID;
-            } else {
-                qCWarning(ClientLogger) << "Failed to create schedule type:" << msg.msg.toString();
-            }
-            // 延迟一秒后再退出
-            // 一来可以避免导入小文件时，进度过快引起等待对话框闪烁
-            // 二来在导入大文件时堵塞dbus调用，延迟可以避免客户端在日程类型更新信号执行的槽函数被堵塞。
-            QTimer::singleShot(1000, &event, &QEventLoop::quit);
-        });
-    } else {
-        // If type exists, just delay for UI consistency
+    // 创建日程类型
+    account->createJobType(type, [&event, &typeID](CallMessge msg) {
+        if (msg.code == 0) {
+            // 记录创建的类型ID
+            typeID = msg.msg.toString();
+            qCDebug(ClientLogger) << "Created schedule type with ID:" << typeID;
+        } else {
+            qCWarning(ClientLogger) << "Failed to create schedule type:" << msg.msg.toString();
+        }
+        // 延迟一秒后再退出
+        // 一来可以避免导入小文件时，进度过快引起等待对话框闪烁
+        // 二来在导入大文件时堵塞dbus调用，延迟可以避免客户端在日程类型更新信号执行的槽函数被堵塞。
         QTimer::singleShot(1000, &event, &QEventLoop::quit);
-    }
+    });
+
     // 等待日程创建完毕
     event.exec();
     // 导入ics文件
