@@ -12,9 +12,10 @@
 const QString CalendarServiceName = "com.deepin.dataserver.Calendar";
 const QString CalendarPath = "/com/deepin/dataserver/Calendar";
 
-const QLoggingCategory CommonLogger("org.deepin.dde-calendar.common");
-const QLoggingCategory ClientLogger("org.deepin.dde-calendar.client");
-const QLoggingCategory ServiceLogger("org.deepin.dde-calendar.service");
+const QLoggingCategory CommonLogger("org.deepin.dde.calendar");
+const QLoggingCategory ClientLogger("org.deepin.dde.calendar.client");
+const QLoggingCategory ServiceLogger("org.deepin.dde.calendar.service");
+const QLoggingCategory PluginLogger("org.deepin.dde.calendar.plugin");
 
 
 #endif // COMMONDEF_H
