@@ -36,7 +36,7 @@ void createSchedulewidget::setTitleName(const QString &titleName)
 
 void createSchedulewidget::setDateTime(QDateTime begintime, QDateTime endtime)
 {
-    qCDebug(CommonLogger) << "Setting schedule time range - Begin:" << begintime << "End:" << endtime;
+    qCDebug(PluginLogger) << "Setting schedule time range - Begin:" << begintime << "End:" << endtime;
     m_BeginDateTime = begintime;
     m_EndDateTime = endtime;
 }
@@ -48,7 +48,7 @@ void createSchedulewidget::setRpeat(int rpeat)
 
 void createSchedulewidget::setschedule()
 {
-    qCDebug(CommonLogger) << "Creating schedule with title:" << m_titleName;
+    qCDebug(PluginLogger) << "Creating schedule with title:" << m_titleName;
     QDateTime m_beginTime;
     QDateTime m_endTime;
     m_beginTime = m_BeginDateTime;
@@ -63,32 +63,32 @@ void createSchedulewidget::setschedule()
     m_scheduleDtailInfo->setAlarmType(DSchedule::Alarm_Begin);
     switch (m_rpeat) {
     case 1:
-        qCDebug(CommonLogger) << "Setting daily repeat rule";
+        qCDebug(PluginLogger) << "Setting daily repeat rule";
         m_scheduleDtailInfo->setRRuleType(DSchedule::RRule_Day);
         break;
     case 2:
-        qCDebug(CommonLogger) << "Setting workday repeat rule";
+        qCDebug(PluginLogger) << "Setting workday repeat rule";
         m_scheduleDtailInfo->setRRuleType(DSchedule::RRule_Work);
         break;
     case 3:
-        qCDebug(CommonLogger) << "Setting weekly repeat rule";
+        qCDebug(PluginLogger) << "Setting weekly repeat rule";
         m_scheduleDtailInfo->setRRuleType(DSchedule::RRule_Week);
         break;
     case 4:
-        qCDebug(CommonLogger) << "Setting monthly repeat rule";
+        qCDebug(PluginLogger) << "Setting monthly repeat rule";
         m_scheduleDtailInfo->setRRuleType(DSchedule::RRule_Month);
         break;
     case 5:
-        qCDebug(CommonLogger) << "Setting yearly repeat rule";
+        qCDebug(PluginLogger) << "Setting yearly repeat rule";
         m_scheduleDtailInfo->setRRuleType(DSchedule::RRule_Year);
         break;
     default:
-        qCDebug(CommonLogger) << "Setting no repeat rule";
+        qCDebug(PluginLogger) << "Setting no repeat rule";
         m_scheduleDtailInfo->setRRuleType(DSchedule::RRule_None);
         break;
     }
     if (m_scheduleDtailInfo->getRRuleType() != DSchedule::RRule_None) {
-        qCDebug(CommonLogger) << "Setting infinite repeat duration";
+        qCDebug(PluginLogger) << "Setting infinite repeat duration";
         //结束重复于类型为：永不
         m_scheduleDtailInfo->recurrence()->setDuration(-1);
     }
@@ -101,24 +101,24 @@ void createSchedulewidget::scheduleEmpty(bool isEmpty)
 
 void createSchedulewidget::updateUI(const QString &scheduleID)
 {
-    qCDebug(CommonLogger) << "Updating UI for schedule ID:" << scheduleID;
+    qCDebug(PluginLogger) << "Updating UI for schedule ID:" << scheduleID;
     if (m_scheduleEmpty) {
-        qCDebug(CommonLogger) << "Schedule is empty, fetching from DBus";
+        qCDebug(PluginLogger) << "Schedule is empty, fetching from DBus";
         //获取筛选到的日程信息
         getCreatScheduleFromDbus(scheduleID);
         //如果筛选到的日程不为空，则展示日程插件
         if (!m_scheduleInfo.isEmpty()) {
-            qCDebug(CommonLogger) << "Creating UI with" << m_scheduleInfo.size() << "schedules";
+            qCDebug(PluginLogger) << "Creating UI with" << m_scheduleInfo.size() << "schedules";
             QVBoxLayout *mainlayout = new QVBoxLayout();
             m_scheduleitemwidget->setScheduleDtailInfo(m_scheduleInfo);
             m_scheduleitemwidget->addscheduleitem();
             mainlayout->addWidget(m_scheduleitemwidget);
             setCenterLayout(mainlayout);
         } else {
-            qCritical(CommonLogger) << "No matching schedule found in database for ID:" << scheduleID;
+            qCritical(PluginLogger) << "No matching schedule found in database for ID:" << scheduleID;
         }
     } else {
-        qCDebug(CommonLogger) << "Creating UI with confirmation buttons";
+        qCDebug(PluginLogger) << "Creating UI with confirmation buttons";
         //是否创建日程
         QVBoxLayout *mainlayout = new QVBoxLayout();
         buttonwidget *button = new buttonwidget(this);
@@ -152,14 +152,14 @@ void createSchedulewidget::slotsbuttonchance(int index, const QString &text)
 
 void createSchedulewidget::slotItemPress(const DSchedule::Ptr &info)
 {
-    qCDebug(CommonLogger) << "Schedule item pressed - ID:" << info->uid() << "Title:" << info->summary();
+    qCDebug(PluginLogger) << "Schedule item pressed - ID:" << info->uid() << "Title:" << info->summary();
     QProcess proc;
-    qCDebug(CommonLogger) << "Launching calendar program";
+    qCDebug(PluginLogger) << "Launching calendar program";
     proc.startDetached(PROCESS_OPEN_CALENDAR_PROGRAM, QString(PROCESS_OPEN_CALENDAR_ARGUMENTS).split(" "));
     QThread::msleep(750);
     QString schedulestr;
     DSchedule::toJsonString(info, schedulestr);
-    qCDebug(CommonLogger) << "Sending OpenSchedule DBus message";
+    qCDebug(PluginLogger) << "Sending OpenSchedule DBus message";
     QDBusMessage message = QDBusMessage::createMethodCall(DBUS_CALENDAR_SERVICE,
                                                           DBUS_CALENDAR_PATCH,
                                                           DBUS_CALENDAR_INTFACE,
@@ -171,7 +171,7 @@ void createSchedulewidget::slotItemPress(const DSchedule::Ptr &info)
 
 void createSchedulewidget::getCreatScheduleFromDbus(const QString &scheduleID)
 {
-    qCDebug(CommonLogger) << "Fetching schedule from DBus - ID:" << scheduleID;
+    qCDebug(PluginLogger) << "Fetching schedule from DBus - ID:" << scheduleID;
     DSchedule::Ptr schedule = DScheduleDataManager::getInstance()->queryScheduleByScheduleID(scheduleID);
     m_scheduleInfo.append(schedule);
 }
